@@ -23,9 +23,10 @@ let version = "%%VERSION%%"
 (* +-----------------------------------------------------------------+
    | History                                                         |
    +-----------------------------------------------------------------+ *)
+module Default_paths = UTop_private.Default_paths
 
 let history = LTerm_history.create []
-let history_file_name = ref (Some (Filename.concat LTerm_resources.home ".utop-history"))
+let history_file_name = ref (Some (Default_paths.history_file_name))
 let history_file_max_size = ref None
 let history_file_max_entries = ref None
 let stashable_session_history = UTop_history.create ()
@@ -359,13 +360,7 @@ let check_phrase phrase =
             (fun () ->
                Str.eval
                  (Exp.fun_ Nolabel None (Pat.construct unit None)
-                   (Exp.letmodule (with_loc loc
-                        #if OCAML_VERSION >= (4, 10, 0)
-                        (Some "_")
-                        #else
-                          "_"
-                        #endif
-                        )
+                   (Exp.letmodule (with_loc loc (Some "_"))
                       (Mod.structure (item :: items))
                       (Exp.construct unit None))))
         in
@@ -836,12 +831,32 @@ let () =
 let get_load_path () = Load_path.get_paths ()
 let set_load_path = UTop_compat.set_load_path
 
-(* +-----------------------------------------------------------------+
-   | Deprecated                                                      |
-   +-----------------------------------------------------------------+ *)
-
-let smart_accept = ref true
-let new_prompt_hooks = LTerm_dlist.create ()
-let at_new_prompt f = ignore (LTerm_dlist.add_l f new_prompt_hooks)
-let prompt_continue = ref (S.const [| |])
-let prompt_comment = ref (S.const [| |])
+module Private = struct
+  let fix_string str =
+    let len = String.length str in
+    if len = 0 then
+      str
+    else
+      let ofs, _, _ = Zed_utf8.next_error str 0 in
+      if ofs = len then
+        str
+      else begin
+        let buf = Buffer.create (len + 128) in
+        if ofs > 0 then Buffer.add_substring buf str 0 ofs;
+        let rec loop ofs =
+          Zed_utf8.add buf (Uchar.of_char str.[ofs]);
+          let ofs1 = ofs + 1 in
+          if ofs1 < len then
+            let ofs2, _, _ = Zed_utf8.next_error str ofs1 in
+            if ofs1 < ofs2 then
+              Buffer.add_substring buf str ofs1 (ofs2 - ofs1);
+            if ofs2 < len then
+              loop ofs2
+            else
+              Buffer.contents buf
+          else
+            Buffer.contents buf
+        in
+        loop ofs
+      end
+end
